@@ -14,7 +14,7 @@ import numpy
 import torch
 import os, sys
 
-
+"""
 seed = 0           
 random.seed(seed)
 torch.manual_seed(seed)
@@ -23,6 +23,7 @@ numpy.random.seed(seed)
 torch.backends.cudnn.deterministic=True
 torch.backends.cudnn.benchmarks=False
 os.environ['PYTHONHASHSEED'] = str(seed)
+"""
 
 ##  watch -d -n 0.5 nvidia-smi
 
@@ -30,7 +31,7 @@ from DLStudio import *
 
 dls = DLStudio(
 #                  dataroot = "/home/kak/ImageDatasets/PurdueShapes5/",
-                  dataroot = "./data/",
+                  dataroot = "./data/PurdueShapes5/",
                   image_size = [32,32],
                   path_saved_model = "./saved_model",
                   momentum = 0.9,
